# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .task_retrieve_response import TaskRetrieveResponse as TaskRetrieveResponse
from .text_to_image_create_params import TextToImageCreateParams as TextToImageCreateParams
from .video_upscale_create_params import VideoUpscaleCreateParams as VideoUpscaleCreateParams
from .image_to_video_create_params import ImageToVideoCreateParams as ImageToVideoCreateParams
from .text_to_image_create_response import TextToImageCreateResponse as TextToImageCreateResponse
from .video_upscale_create_response import VideoUpscaleCreateResponse as VideoUpscaleCreateResponse
from .image_to_video_create_response import ImageToVideoCreateResponse as ImageToVideoCreateResponse
from .organization_retrieve_response import OrganizationRetrieveResponse as OrganizationRetrieveResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Iterable
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["ImageToVideoCreateParams", "PromptImagePromptImage", "ContentModeration"]


class ImageToVideoCreateParams(TypedDict, total=False):
    model: Required[Literal["gen3a_turbo", "gen4_turbo"]]
    """The model variant to use."""

    prompt_image: Required[Annotated[Union[str, Iterable[PromptImagePromptImage]], PropertyInfo(alias="promptImage")]]
    """
    A HTTPS URL or data URI containing an encoded image to be used as the first
    frame of the generated video. See [our docs](/assets/inputs#images) on image
    inputs for more information.
    """

    ratio: Required[
        Literal["1280:720", "720:1280", "1104:832", "832:1104", "960:960", "1584:672", "1280:768", "768:1280"]
    ]
    """The resolution of the output video.

    `gen4_turbo` supports the following values:

    - `1280:720`
    - `720:1280`
    - `1104:832`
    - `832:1104`
    - `960:960`
    - `1584:672`

    `gen3a_turbo` supports the following values:

    - `1280:768`
    - `768:1280`
    """

    content_moderation: Annotated[ContentModeration, PropertyInfo(alias="contentModeration")]
    """Settings that affect the behavior of the content moderation system."""

    duration: Literal[5, 10]
    """The number of seconds of duration for the output video."""

    prompt_text: Annotated[str, PropertyInfo(alias="promptText")]
    """A non-empty string up to 1000 characters (measured in UTF-16 code units).

    This should describe in detail what should appear in the output.
    """

    seed: int
    """If unspecified, a random number is chosen.

    Varying the seed integer is a way to get different results for the same other
    request parameters. Using the same seed integer for an identical request will
    produce similar results.
    """


class PromptImagePromptImage(TypedDict, total=False):
    position: Required[Literal["first", "last"]]
    """The position of the image in the output video.

    "first" will use the image as the first frame of the video, "last" will use the
    image as the last frame of the video.

    "last" is currently supported for `gen3a_turbo` only.
    """

    uri: Required[str]
    """A HTTPS URL or data URI containing an encoded image.

    See [our docs](/assets/inputs#images) on image inputs for more information.
    """


class ContentModeration(TypedDict, total=False):
    public_figure_threshold: Annotated[Literal["auto", "low"], PropertyInfo(alias="publicFigureThreshold")]
    """
    When set to `low`, the content moderation system will be less strict about
    preventing generations that include recognizable public figures.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ..types import video_upscale_create_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..lib.polling import (
    NewTaskCreatedResponse,
    AsyncNewTaskCreatedResponse,
    create_waitable_resource,
    create_async_waitable_resource,
)
from .._base_client import make_request_options
from ..types.video_upscale_create_response import VideoUpscaleCreateResponse

__all__ = ["VideoUpscaleResource", "AsyncVideoUpscaleResource"]


class VideoUpscaleResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> VideoUpscaleResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/runwayml/sdk-python#accessing-raw-response-data-eg-headers
        """
        return VideoUpscaleResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> VideoUpscaleResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/runwayml/sdk-python#with_streaming_response
        """
        return VideoUpscaleResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        model: Literal["upscale_v1"],
        video_uri: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> NewTaskCreatedResponse:
        """This endpoint will start a new task to upscale a video.

        Videos will be upscaled
        by a factor of 4X, capped at a maximum of 4096px along each side.

        Args:
          model: The model variant to use.

          video_uri: A HTTPS URL pointing to a video or a data URI containing a video. The video must
              be less than 4096px on each side. The video duration may not exceed 40 seconds.
              See [our docs](/assets/inputs#videos) on video inputs for more information.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/video_upscale",
            body=maybe_transform(
                {
                    "model": model,
                    "video_uri": video_uri,
                },
                video_upscale_create_params.VideoUpscaleCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=create_waitable_resource(VideoUpscaleCreateResponse, self._client),
        )


class AsyncVideoUpscaleResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncVideoUpscaleResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/runwayml/sdk-python#accessing-raw-response-data-eg-headers
        """
        return AsyncVideoUpscaleResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncVideoUpscaleResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/runwayml/sdk-python#with_streaming_response
        """
        return AsyncVideoUpscaleResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        model: Literal["upscale_v1"],
        video_uri: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AsyncNewTaskCreatedResponse:
        """This endpoint will start a new task to upscale a video.

        Videos will be upscaled
        by a factor of 4X, capped at a maximum of 4096px along each side.

        Args:
          model: The model variant to use.

          video_uri: A HTTPS URL pointing to a video or a data URI containing a video. The video must
              be less than 4096px on each side. The video duration may not exceed 40 seconds.
              See [our docs](/assets/inputs#videos) on video inputs for more information.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/video_upscale",
            body=await async_maybe_transform(
                {
                    "model": model,
                    "video_uri": video_uri,
                },
                video_upscale_create_params.VideoUpscaleCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=create_async_waitable_resource(VideoUpscaleCreateResponse, self._client),
        )


class VideoUpscaleResourceWithRawResponse:
    def __init__(self, video_upscale: VideoUpscaleResource) -> None:
        self._video_upscale = video_upscale

        self.create = to_raw_response_wrapper(
            video_upscale.create,
        )


class AsyncVideoUpscaleResourceWithRawResponse:
    def __init__(self, video_upscale: AsyncVideoUpscaleResource) -> None:
        self._video_upscale = video_upscale

        self.create = async_to_raw_response_wrapper(
            video_upscale.create,
        )


class VideoUpscaleResourceWithStreamingResponse:
    def __init__(self, video_upscale: VideoUpscaleResource) -> None:
        self._video_upscale = video_upscale

        self.create = to_streamed_response_wrapper(
            video_upscale.create,
        )


class AsyncVideoUpscaleResourceWithStreamingResponse:
    def __init__(self, video_upscale: AsyncVideoUpscaleResource) -> None:
        self._video_upscale = video_upscale

        self.create = async_to_streamed_response_wrapper(
            video_upscale.create,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Iterable
from typing_extensions import Literal

import httpx

from ..types import image_to_video_create_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..lib.polling import (
    NewTaskCreatedResponse,
    AsyncNewTaskCreatedResponse,
    create_waitable_resource,
    create_async_waitable_resource,
)
from .._base_client import make_request_options
from ..types.image_to_video_create_response import ImageToVideoCreateResponse

__all__ = ["ImageToVideoResource", "AsyncImageToVideoResource"]


class ImageToVideoResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ImageToVideoResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/runwayml/sdk-python#accessing-raw-response-data-eg-headers
        """
        return ImageToVideoResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ImageToVideoResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/runwayml/sdk-python#with_streaming_response
        """
        return ImageToVideoResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        model: Literal["gen3a_turbo", "gen4_turbo"],
        prompt_image: Union[str, Iterable[image_to_video_create_params.PromptImagePromptImage]],
        ratio: Literal["1280:720", "720:1280", "1104:832", "832:1104", "960:960", "1584:672", "1280:768", "768:1280"],
        content_moderation: image_to_video_create_params.ContentModeration | NotGiven = NOT_GIVEN,
        duration: Literal[5, 10] | NotGiven = NOT_GIVEN,
        prompt_text: str | NotGiven = NOT_GIVEN,
        seed: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> NewTaskCreatedResponse:
        """
        This endpoint will start a new task to generate a video from an image prompt.

        Args:
          model: The model variant to use.

          prompt_image: A HTTPS URL or data URI containing an encoded image to be used as the first
              frame of the generated video. See [our docs](/assets/inputs#images) on image
              inputs for more information.

          ratio: The resolution of the output video.

              `gen4_turbo` supports the following values:

              - `1280:720`
              - `720:1280`
              - `1104:832`
              - `832:1104`
              - `960:960`
              - `1584:672`

              `gen3a_turbo` supports the following values:

              - `1280:768`
              - `768:1280`

          content_moderation: Settings that affect the behavior of the content moderation system.

          duration: The number of seconds of duration for the output video.

          prompt_text: A non-empty string up to 1000 characters (measured in UTF-16 code units). This
              should describe in detail what should appear in the output.

          seed: If unspecified, a random number is chosen. Varying the seed integer is a way to
              get different results for the same other request parameters. Using the same seed
              integer for an identical request will produce similar results.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/image_to_video",
            body=maybe_transform(
                {
                    "model": model,
                    "prompt_image": prompt_image,
                    "ratio": ratio,
                    "content_moderation": content_moderation,
                    "duration": duration,
                    "prompt_text": prompt_text,
                    "seed": seed,
                },
                image_to_video_create_params.ImageToVideoCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=create_waitable_resource(ImageToVideoCreateResponse, self._client),
        )


class AsyncImageToVideoResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncImageToVideoResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/runwayml/sdk-python#accessing-raw-response-data-eg-headers
        """
        return AsyncImageToVideoResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncImageToVideoResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/runwayml/sdk-python#with_streaming_response
        """
        return AsyncImageToVideoResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        model: Literal["gen3a_turbo", "gen4_turbo"],
        prompt_image: Union[str, Iterable[image_to_video_create_params.PromptImagePromptImage]],
        ratio: Literal["1280:720", "720:1280", "1104:832", "832:1104", "960:960", "1584:672", "1280:768", "768:1280"],
        content_moderation: image_to_video_create_params.ContentModeration | NotGiven = NOT_GIVEN,
        duration: Literal[5, 10] | NotGiven = NOT_GIVEN,
        prompt_text: str | NotGiven = NOT_GIVEN,
        seed: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AsyncNewTaskCreatedResponse:
        """
        This endpoint will start a new task to generate a video from an image prompt.

        Args:
          model: The model variant to use.

          prompt_image: A HTTPS URL or data URI containing an encoded image to be used as the first
              frame of the generated video. See [our docs](/assets/inputs#images) on image
              inputs for more information.

          ratio: The resolution of the output video.

              `gen4_turbo` supports the following values:

              - `1280:720`
              - `720:1280`
              - `1104:832`
              - `832:1104`
              - `960:960`
              - `1584:672`

              `gen3a_turbo` supports the following values:

              - `1280:768`
              - `768:1280`

          content_moderation: Settings that affect the behavior of the content moderation system.

          duration: The number of seconds of duration for the output video.

          prompt_text: A non-empty string up to 1000 characters (measured in UTF-16 code units). This
              should describe in detail what should appear in the output.

          seed: If unspecified, a random number is chosen. Varying the seed integer is a way to
              get different results for the same other request parameters. Using the same seed
              integer for an identical request will produce similar results.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/image_to_video",
            body=await async_maybe_transform(
                {
                    "model": model,
                    "prompt_image": prompt_image,
                    "ratio": ratio,
                    "content_moderation": content_moderation,
                    "duration": duration,
                    "prompt_text": prompt_text,
                    "seed": seed,
                },
                image_to_video_create_params.ImageToVideoCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=create_async_waitable_resource(ImageToVideoCreateResponse, self._client),
        )


class ImageToVideoResourceWithRawResponse:
    def __init__(self, image_to_video: ImageToVideoResource) -> None:
        self._image_to_video = image_to_video

        self.create = to_raw_response_wrapper(
            image_to_video.create,
        )


class AsyncImageToVideoResourceWithRawResponse:
    def __init__(self, image_to_video: AsyncImageToVideoResource) -> None:
        self._image_to_video = image_to_video

        self.create = async_to_raw_response_wrapper(
            image_to_video.create,
        )


class ImageToVideoResourceWithStreamingResponse:
    def __init__(self, image_to_video: ImageToVideoResource) -> None:
        self._image_to_video = image_to_video

        self.create = to_streamed_response_wrapper(
            image_to_video.create,
        )


class AsyncImageToVideoResourceWithStreamingResponse:
    def __init__(self, image_to_video: AsyncImageToVideoResource) -> None:
        self._image_to_video = image_to_video

        self.create = async_to_streamed_response_wrapper(
            image_to_video.create,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel

__all__ = ["VideoUpscaleCreateResponse"]


class VideoUpscaleCreateResponse(BaseModel):
    id: str
    """The ID of the newly created task."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel

__all__ = ["ImageToVideoCreateResponse"]


class ImageToVideoCreateResponse(BaseModel):
    id: str
    """The ID of the newly created task.

    Use this ID to query the task status and retrieve the generated video.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .tasks import (
    TasksResource,
    AsyncTasksResource,
    TasksResourceWithRawResponse,
    AsyncTasksResourceWithRawResponse,
    TasksResourceWithStreamingResponse,
    AsyncTasksResourceWithStreamingResponse,
)
from .organization import (
    OrganizationResource,
    AsyncOrganizationResource,
    OrganizationResourceWithRawResponse,
    AsyncOrganizationResourceWithRawResponse,
    OrganizationResourceWithStreamingResponse,
    AsyncOrganizationResourceWithStreamingResponse,
)
from .text_to_image import (
    TextToImageResource,
    AsyncTextToImageResource,
    TextToImageResourceWithRawResponse,
    AsyncTextToImageResourceWithRawResponse,
    TextToImageResourceWithStreamingResponse,
    AsyncTextToImageResourceWithStreamingResponse,
)
from .video_upscale import (
    VideoUpscaleResource,
    AsyncVideoUpscaleResource,
    VideoUpscaleResourceWithRawResponse,
    AsyncVideoUpscaleResourceWithRawResponse,
    VideoUpscaleResourceWithStreamingResponse,
    AsyncVideoUpscaleResourceWithStreamingResponse,
)
from .image_to_video import (
    ImageToVideoResource,
    AsyncImageToVideoResource,
    ImageToVideoResourceWithRawResponse,
    AsyncImageToVideoResourceWithRawResponse,
    ImageToVideoResourceWithStreamingResponse,
    AsyncImageToVideoResourceWithStreamingResponse,
)

__all__ = [
    "TasksResource",
    "AsyncTasksResource",
    "TasksResourceWithRawResponse",
    "AsyncTasksResourceWithRawResponse",
    "TasksResourceWithStreamingResponse",
    "AsyncTasksResourceWithStreamingResponse",
    "ImageToVideoResource",
    "AsyncImageToVideoResource",
    "ImageToVideoResourceWithRawResponse",
    "AsyncImageToVideoResourceWithRawResponse",
    "ImageToVideoResourceWithStreamingResponse",
    "AsyncImageToVideoResourceWithStreamingResponse",
    "TextToImageResource",
    "AsyncTextToImageResource",
    "TextToImageResourceWithRawResponse",
    "AsyncTextToImageResourceWithRawResponse",
    "TextToImageResourceWithStreamingResponse",
    "AsyncTextToImageResourceWithStreamingResponse",
    "VideoUpscaleResource",
    "AsyncVideoUpscaleResource",
    "VideoUpscaleResourceWithRawResponse",
    "AsyncVideoUpscaleResourceWithRawResponse",
    "VideoUpscaleResourceWithStreamingResponse",
    "AsyncVideoUpscaleResourceWithStreamingResponse",
    "OrganizationResource",
    "AsyncOrganizationResource",
    "OrganizationResourceWithRawResponse",
    "AsyncOrganizationResourceWithRawResponse",
    "OrganizationResourceWithStreamingResponse",
    "AsyncOrganizationResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["TextToImageCreateParams", "ContentModeration", "ReferenceImage"]


class TextToImageCreateParams(TypedDict, total=False):
    model: Required[Literal["gen4_image"]]
    """The model variant to use."""

    prompt_text: Required[Annotated[str, PropertyInfo(alias="promptText")]]
    """A non-empty string up to 1000 characters (measured in UTF-16 code units).

    This should describe in detail what should appear in the output.
    """

    ratio: Required[
        Literal[
            "1920:1080",
            "1080:1920",
            "1024:1024",
            "1360:768",
            "1080:1080",
            "1168:880",
            "1440:1080",
            "1080:1440",
            "1808:768",
            "2112:912",
            "1280:720",
            "720:1280",
            "720:720",
            "960:720",
            "720:960",
            "1680:720",
        ]
    ]
    """The resolution of the output image(s)."""

    content_moderation: Annotated[ContentModeration, PropertyInfo(alias="contentModeration")]
    """Settings that affect the behavior of the content moderation system."""

    reference_images: Annotated[Iterable[ReferenceImage], PropertyInfo(alias="referenceImages")]
    """An array of images to be used as references for the generated image output.

    Up to three reference images can be provided.
    """

    seed: int
    """If unspecified, a random number is chosen.

    Varying the seed integer is a way to get different results for the same other
    request parameters. Using the same seed integer for an identical request will
    produce similar results.
    """


class ContentModeration(TypedDict, total=False):
    public_figure_threshold: Annotated[Literal["auto", "low"], PropertyInfo(alias="publicFigureThreshold")]
    """
    When set to `low`, the content moderation system will be less strict about
    preventing generations that include recognizable public figures.
    """


class ReferenceImage(TypedDict, total=False):
    uri: Required[str]
    """
    A HTTPS URL or data URI containing an encoded image to be used as reference for
    the generated output image. See [our docs](/assets/inputs#images) on image
    inputs for more information.
    """

    tag: str
    """A name used to refer to the image reference, from 3 to 16 characters in length.

    Tags must be alphanumeric (plus underscores) and start with a letter. You can
    refer to the reference image's tag in the prompt text with at-mention syntax:
    `@tag`. Tags are case-sensitive.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = [
    "OrganizationRetrieveResponse",
    "Tier",
    "TierModels",
    "TierModelsGen3aTurbo",
    "TierModelsGen4Image",
    "TierModelsGen4Turbo",
    "TierModelsUpscaleV1",
    "Usage",
    "UsageModels",
    "UsageModelsGen3aTurbo",
    "UsageModelsGen4Image",
    "UsageModelsGen4Turbo",
    "UsageModelsUpscaleV1",
]


class TierModelsGen3aTurbo(BaseModel):
    max_concurrent_generations: int = FieldInfo(alias="maxConcurrentGenerations")
    """The maximum number of generations that can be run concurrently for this model."""

    max_daily_generations: int = FieldInfo(alias="maxDailyGenerations")
    """The maximum number of generations that can be created each day for this model."""


class TierModelsGen4Image(BaseModel):
    max_concurrent_generations: int = FieldInfo(alias="maxConcurrentGenerations")
    """The maximum number of generations that can be run concurrently for this model."""

    max_daily_generations: int = FieldInfo(alias="maxDailyGenerations")
    """The maximum number of generations that can be created each day for this model."""


class TierModelsGen4Turbo(BaseModel):
    max_concurrent_generations: int = FieldInfo(alias="maxConcurrentGenerations")
    """The maximum number of generations that can be run concurrently for this model."""

    max_daily_generations: int = FieldInfo(alias="maxDailyGenerations")
    """The maximum number of generations that can be created each day for this model."""


class TierModelsUpscaleV1(BaseModel):
    max_concurrent_generations: int = FieldInfo(alias="maxConcurrentGenerations")
    """The maximum number of generations that can be run concurrently for this model."""

    max_daily_generations: int = FieldInfo(alias="maxDailyGenerations")
    """The maximum number of generations that can be created each day for this model."""


class TierModels(BaseModel):
    gen3a_turbo: Optional[TierModelsGen3aTurbo] = None
    """Limits associated with the gen3a_turbo model."""

    gen4_image: Optional[TierModelsGen4Image] = None
    """Limits associated with the gen4_image model."""

    gen4_turbo: Optional[TierModelsGen4Turbo] = None
    """Limits associated with the gen4_turbo model."""

    upscale_v1: Optional[TierModelsUpscaleV1] = None
    """Limits associated with the upscale_v1 model."""


class Tier(BaseModel):
    max_monthly_credit_spend: int = FieldInfo(alias="maxMonthlyCreditSpend")
    """The maximum number of credits that can be purchased in a month."""

    models: TierModels
    """An object containing model-specific limits. Each key represents a model."""


class UsageModelsGen3aTurbo(BaseModel):
    daily_generations: int = FieldInfo(alias="dailyGenerations")
    """The number of generations that have been run for this model in the past day."""


class UsageModelsGen4Image(BaseModel):
    daily_generations: int = FieldInfo(alias="dailyGenerations")
    """The number of generations that have been run for this model in the past day."""


class UsageModelsGen4Turbo(BaseModel):
    daily_generations: int = FieldInfo(alias="dailyGenerations")
    """The number of generations that have been run for this model in the past day."""


class UsageModelsUpscaleV1(BaseModel):
    daily_generations: int = FieldInfo(alias="dailyGenerations")
    """The number of generations that have been run for this model in the past day."""


class UsageModels(BaseModel):
    gen3a_turbo: Optional[UsageModelsGen3aTurbo] = None
    """Usage data for the gen3a_turbo model."""

    gen4_image: Optional[UsageModelsGen4Image] = None
    """Usage data for the gen4_image model."""

    gen4_turbo: Optional[UsageModelsGen4Turbo] = None
    """Usage data for the gen4_turbo model."""

    upscale_v1: Optional[UsageModelsUpscaleV1] = None
    """Usage data for the upscale_v1 model."""


class Usage(BaseModel):
    models: UsageModels
    """Usage data for each model."""


class OrganizationRetrieveResponse(BaseModel):
    credit_balance: int = FieldInfo(alias="creditBalance")
    """The number of credits remaining in the organization account."""

    tier: Tier
    """Limits associated with the organization's tier."""

    usage: Usage
    """Usage data for the organization."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["TaskRetrieveResponse"]


class TaskRetrieveResponse(BaseModel):
    id: str
    """The ID of the task being returned."""

    created_at: datetime = FieldInfo(alias="createdAt")
    """The timestamp that the task was submitted at."""

    status: Literal["RUNNING", "SUCCEEDED", "FAILED", "PENDING", "CANCELLED", "THROTTLED"]
    """
    - `PENDING` tasks have been enqueued and are waiting to run.
    - `THROTTLED` tasks are waiting to be enqueued until other jobs have finished
      running.
    - `RUNNING` tasks are currently being processed.
    - `SUCCEEDED` tasks have completed successfully.
    - `FAILED` tasks have failed.
    - `CANCELLED` tasks have been aborted.
    """

    failure: Optional[str] = None
    """
    If the status is `FAILED`, this will contain a human-friendly reason for the
    failure.
    """

    failure_code: Optional[str] = FieldInfo(alias="failureCode", default=None)
    """
    If the task has a status of `FAILED`, this contains a machine-readable error
    code. This is a dot-separated string, with the leftmost segment being the most
    generic and the rightmost segment being the most specific. For example,
    `SAFETY.INPUT.TEXT` would indicate that the task failed due to a content
    moderation error on the input text.
    """

    output: Optional[List[str]] = None
    """If the status is `SUCCEEDED`, this will contain an array of strings.

    Each string will be a URL that returns an output from the task. URLs expire
    within 24-48 hours; fetch the task again to get fresh URLs. It is expected that
    you download the assets at these URLs and store them in your own storage system.
    """

    progress: Optional[float] = None
    """
    If the task has a status of `RUNNING`, this will contain a floating point number
    between 0 and 1 representing the progress of the generation.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["VideoUpscaleCreateParams"]


class VideoUpscaleCreateParams(TypedDict, total=False):
    model: Required[Literal["upscale_v1"]]
    """The model variant to use."""

    video_uri: Required[Annotated[str, PropertyInfo(alias="videoUri")]]
    """A HTTPS URL pointing to a video or a data URI containing a video.

    The video must be less than 4096px on each side. The video duration may not
    exceed 40 seconds. See [our docs](/assets/inputs#videos) on video inputs for
    more information.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from runwayml import RunwayML, AsyncRunwayML
from tests.utils import assert_matches_type
from runwayml.types import TextToImageCreateResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestTextToImage:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create(self, client: RunwayML) -> None:
        text_to_image = client.text_to_image.create(
            model="gen4_image",
            prompt_text="promptText",
            ratio="1920:1080",
        )
        assert_matches_type(TextToImageCreateResponse, text_to_image, path=["response"])

    @parametrize
    def test_method_create_with_all_params(self, client: RunwayML) -> None:
        text_to_image = client.text_to_image.create(
            model="gen4_image",
            prompt_text="promptText",
            ratio="1920:1080",
            content_moderation={"public_figure_threshold": "auto"},
            reference_images=[
                {
                    "uri": "https://example.com",
                    "tag": "tag",
                }
            ],
            seed=0,
        )
        assert_matches_type(TextToImageCreateResponse, text_to_image, path=["response"])

    @parametrize
    def test_raw_response_create(self, client: RunwayML) -> None:
        response = client.text_to_image.with_raw_response.create(
            model="gen4_image",
            prompt_text="promptText",
            ratio="1920:1080",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        text_to_image = response.parse()
        assert_matches_type(TextToImageCreateResponse, text_to_image, path=["response"])

    @parametrize
    def test_streaming_response_create(self, client: RunwayML) -> None:
        with client.text_to_image.with_streaming_response.create(
            model="gen4_image",
            prompt_text="promptText",
            ratio="1920:1080",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            text_to_image = response.parse()
            assert_matches_type(TextToImageCreateResponse, text_to_image, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncTextToImage:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_create(self, async_client: AsyncRunwayML) -> None:
        text_to_image = await async_client.text_to_image.create(
            model="gen4_image",
            prompt_text="promptText",
            ratio="1920:1080",
        )
        assert_matches_type(TextToImageCreateResponse, text_to_image, path=["response"])

    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncRunwayML) -> None:
        text_to_image = await async_client.text_to_image.create(
            model="gen4_image",
            prompt_text="promptText",
            ratio="1920:1080",
            content_moderation={"public_figure_threshold": "auto"},
            reference_images=[
                {
                    "uri": "https://example.com",
                    "tag": "tag",
                }
            ],
            seed=0,
        )
        assert_matches_type(TextToImageCreateResponse, text_to_image, path=["response"])

    @parametrize
    async def test_raw_response_create(self, async_client: AsyncRunwayML) -> None:
        response = await async_client.text_to_image.with_raw_response.create(
            model="gen4_image",
            prompt_text="promptText",
            ratio="1920:1080",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        text_to_image = await response.parse()
        assert_matches_type(TextToImageCreateResponse, text_to_image, path=["response"])

    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncRunwayML) -> None:
        async with async_client.text_to_image.with_streaming_response.create(
            model="gen4_image",
            prompt_text="promptText",
            ratio="1920:1080",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            text_to_image = await response.parse()
            assert_matches_type(TextToImageCreateResponse, text_to_image, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.organization_retrieve_response import OrganizationRetrieveResponse

__all__ = ["OrganizationResource", "AsyncOrganizationResource"]


class OrganizationResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> OrganizationResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/runwayml/sdk-python#accessing-raw-response-data-eg-headers
        """
        return OrganizationResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> OrganizationResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/runwayml/sdk-python#with_streaming_response
        """
        return OrganizationResourceWithStreamingResponse(self)

    def retrieve(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> OrganizationRetrieveResponse:
        """
        Get usage tier and credit balance information about the organization associated
        with the API key used to make the request.
        """
        return self._get(
            "/v1/organization",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OrganizationRetrieveResponse,
        )


class AsyncOrganizationResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncOrganizationResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/runwayml/sdk-python#accessing-raw-response-data-eg-headers
        """
        return AsyncOrganizationResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncOrganizationResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/runwayml/sdk-python#with_streaming_response
        """
        return AsyncOrganizationResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> OrganizationRetrieveResponse:
        """
        Get usage tier and credit balance information about the organization associated
        with the API key used to make the request.
        """
        return await self._get(
            "/v1/organization",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OrganizationRetrieveResponse,
        )


class OrganizationResourceWithRawResponse:
    def __init__(self, organization: OrganizationResource) -> None:
        self._organization = organization

        self.retrieve = to_raw_response_wrapper(
            organization.retrieve,
        )


class AsyncOrganizationResourceWithRawResponse:
    def __init__(self, organization: AsyncOrganizationResource) -> None:
        self._organization = organization

        self.retrieve = async_to_raw_response_wrapper(
            organization.retrieve,
        )


class OrganizationResourceWithStreamingResponse:
    def __init__(self, organization: OrganizationResource) -> None:
        self._organization = organization

        self.retrieve = to_streamed_response_wrapper(
            organization.retrieve,
        )


class AsyncOrganizationResourceWithStreamingResponse:
    def __init__(self, organization: AsyncOrganizationResource) -> None:
        self._organization = organization

        self.retrieve = async_to_streamed_response_wrapper(
            organization.retrieve,
        )
